@@ -1304,6 +1304,34 @@ class MpsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ExecuteFunction(self, request):
+        """本接口仅用于定制开发的特殊场景，除非云视频处理客服人员主动告知您需要使用本接口，其它情况请勿调用。
+
+        :param request: Request instance for ExecuteFunction.
+        :type request: :class:`tencentcloud.mps.v20190612.models.ExecuteFunctionRequest`
+        :rtype: :class:`tencentcloud.mps.v20190612.models.ExecuteFunctionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ExecuteFunction", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ExecuteFunctionResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ManageTask(self, request):
         """对已发起的任务进行管理。
         > 注意：目前仅支持终止执行中的直播流处理任务。
@@ -1732,7 +1760,8 @@ class MpsClient(AbstractClient):
     def ProcessLiveStream(self, request):
         """对直播流媒体发起处理任务，功能包括：
 
-        * 智能内容审核（画面鉴黄、鉴政、鉴暴、声音鉴黄）。
+        * 智能内容审核（画面鉴黄、鉴政、鉴暴、声音鉴黄）；
+        * 智能内容识别（人脸、文本全文、文本关键词、语音全文、语音关键词）。
 
         直播流处理事件通知实时写入用户指定的消息队列 CMQ 中，用户需要从消息队列 CMQ 中获取事件通知结果，同时处理过程中存在输出文件的，会写入用户指定的输出文件的目标存储中。
 
